;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Command for GNU Emacs which comments out a region.
;;; Copyright (c) 1987 Michael D. Prange
;;; Written by Michael D. Prange (mit-eddie!mit-erl!prange).

;;; This file is not part of the GNU Emacs distribution (yet).

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY.  No author or distributor
;; accepts responsibility to anyone for the consequences of using it
;; or for whether it serves any particular purpose or works at all,
;; unless he says so in writing.  Refer to the GNU Emacs General Public
;; License for full details.

;; Everyone is granted permission to copy, modify and redistribute
;; this file, but only under the conditions described in the
;; GNU Emacs General Public License.   A copy of this license is
;; supposed to have been given to you along with GNU Emacs so you
;; can know your rights and responsibilities.  It should be in a
;; file named COPYING.  Among other things, the copyright notice
;; and this notice must be preserved on all copies.

(global-set-key "\C-c;" 'comment-region)

(defpvs comment-region editing (start end &optional arg)
  "Comment out all lines in the current region.

The comment-region command comments all the lines in the current
region. With arg, un-comments region that was commented by comment region.
When calling from a program, the arguments are the START and END of the
region, and the optional ARG."
  (interactive "r\nP")
  (save-excursion
    (let ((start (progn (goto-char (max start (point-min)))
			(skip-chars-forward " \t\n") ;skip blank lines
			(beginning-of-line)
			(point)))
	  (end (progn (goto-char (min end (point-max)))
		      (if (or (bolp)
			      (looking-at "[ \t]*$"))
			  (skip-chars-backward " \t\n")) ;skip blank lines
		      (end-of-line)
		      (point))))
      (goto-char end)
      (if (null arg)
	  ;;Comment Region
	  (if (string-equal comment-end "")
	      ;;When no comment-end exists, put a comment-start
	      ;;at the start of each line.
	      (while (and (>= (point) start)
			  (progn (beginning-of-line)
				 (insert-string comment-start)
				 (= (forward-line -1) 0)))
		)
	    ;;When comment-end exists, put comment marks only at the
	    ;;beginning and end of the region, and put a comment-start after
	    ;;each comment-end in the region.
	    (insert-string comment-end)
	    (goto-char end)
	    (while (search-backward comment-end start 'move)
	      (replace-match (concat comment-end comment-start))
	      (goto-char (match-beginning 0)))
	    (insert-string comment-start))
	;;Uncomment Region
	(if (string-equal comment-end "")
	    (while (and (>= (point) start)
			(progn (beginning-of-line)
			       (if (looking-at (regexp-quote comment-start))
				   (replace-match ""))
			       (= (forward-line -1) 0)))
	      )
	  (backward-char (length comment-end))
	  (if (looking-at (regexp-quote comment-end))
	      (replace-match ""))
	  (while (re-search-backward (regexp-quote (concat comment-end comment-start))
				     start 'move)
	    (replace-match comment-end))
	  (if (looking-at (regexp-quote comment-start))
	      (replace-match "")))))))

;;; From: lrs@esl.COM (Lynn Slater)
;;; Path: zodiac!sri-spam!ames!amdcad!cae780!leadsv!esl!lrs
(defun insert-box (start end text)
  "Insert a text prefix at a column in all the lines in the region.
Called from a program, takes three arguments, START, END, and TEXT.
The column is taken from that of START."
  (interactive "r\nsText To Insert: ")
  (save-excursion
    (let (cc)
      ;; the point-marker stuff is needed to keep the edits from changing
      ;; where end is
      (goto-char end)
      (setq end (point-marker))
      (goto-char start)
      (setq cc  (current-column))
      (while (< (point) end) ;; modified 2/2/88
	;; I should here check for tab chars
	(insert text)
	(forward-line 1)
	(move-to-column cc))
      (move-marker end nil))))
