
;;; pvs-help

(defvar pvs-documentation
  "			PVS System Command List

Commands appearing below are given with their abbreviations and alternate
forms when they exist.  For example, the format \"parse, ps (\\[parse])\"
means that the parse command can be invoked by \"M-x parse\", the abbreviated
form \"M-x ps\", or the alternate form \"\\[parse]\".  Most of these commands
support completion on the arguments; hit the space bar at any point to
see what the possible completions are.

Type \\[scroll-up] for next page, \\[scroll-down] for previous one,
\\[beginning-of-buffer] to go to the beginning, \\[end-of-buffer] to end.

	   * Commands preceded by a '*' are not yet available

-----------------------------Basic Commands-----------------------------------

parse, ps (\\[parse])         Parse file in current buffer 
typecheck, tc (\\[typecheck])     Typecheck file in current buffer
typecheck-prove, tcp        Typecheck file in current buffer, proving TCCs
prove, pr (C-c P)           Prove formula pointed to by cursor
prove-theory, prt           Do all proofs in specified theory
*prove-file, prf            Do all the proofs in current file
*proveall-theories, prat    Do prove-theory on all theories on USING chain
*proveall-files, praf       Do prove-file on all files in the context
*prettyprint-region, ppr    Prettyprint region of current buffer
*prettyprint-theory, ppt    Prettyprint theory in current buffer
prettyprint-file, ppf       Prettyprint file in current buffer
prettyprint-expanded, ppe   Prettyprint expanded theory in new buffer
view-prelude-file, vpf      View the prelude file
view-prelude-theory, vpt    View the specified prelude theory

------------------------File and Theory Commands------------------------------

find-pvs-file, ff (C-c C-f) Find buffer containing named PVS file
*find-theory, ft            Find buffer containing named theory
new-pvs-file, nf            Create PVS buffer containing named theory
*new-theory, nt             Create named theory in current buffer
import-pvs-file, imf        Import a text file as a PVS file
*import-theory, imt         Import a theory into the current buffer
delete-pvs-file, df         Delete PVS file
*delete-theory, dt          Delete theory from PVS file
forward-theory, (M-])       Move forward to beginning of next theory
backward-theory, (M-[)      Move backward to beginning of previous theory
find-unbalanced-pvs (C-c ]) Find unbalanced delimiters
save-file, (C-x C-s)        Save file in current buffer
save-some-pvs-files, ssf    Save modified PVS files
dump-pvs-files              Write files in USING chain to file
undump-pvs-files            Break dump file into separate PVS files

---------------------------Printing Commands----------------------------------

print-theory, pt            Send theory to printer
*print-theories, pts        Send theories in using chain to printer
print-pvs-file, pf          Send PVS file to printer
print-pvs-files, pfs        Send PVS files to printer
alltt-print, ap             Format theory for LaTeX alltt environment
alltt-printall, apall       Format theories in using chain for LaTeX alltt
alltt-print-pvs-file, apf   Format theories of file for LaTeX alltt
alltt-print-pvs-files, apfs Format theories of files for LaTeX alltt
latex-print, lp	            Generate LaTeX text for theory
latex-printall, lpall       Generate LaTeX text for theories in using chain
latex-print-pvs-file, lpf   Generate LaTeX text for PVS file
latex-print-pvs-files, lpfs Generate LaTeX text for PVS files

----------------------------Context Commands----------------------------------

*list-pvs-files, lf         Display a list of PVS files in current context
*list-theories, lt          Display a list of theories in current context
change-context, cc          Switch to a new context
save-context, sc            Save the current context
show-context-path, pwd      Display pathname of current context

-----------------------Cross Referencing Commands-----------------------------

show-declaration (M-.)      Show declaration of symbol at cursor
declaration (M-,)           Search for declarations of given symbol
whereis (M-,)               Search for declarations which reference symbol
list-declarations           Produce list of declarations of current context

--------------------------Environment Commands--------------------------------

help (C-h p, C-c h)         Display this help file
whereis-pvs                 Display the root PVS directory
pvs-version                 Display current version of PVS
pvs-mode                    Put current buffer in PVS mode
pvs-status                  Find out if Lisp is busy
reset-pvs                   Abort and resynchronize
remove-popup-buffer (C-z 1) Remove the popup buffer
suspend-pvs (C-c C-z)       Suspend PVS
exit-pvs (C-c C-c)          Terminate PVS session

----------------------------Status Commands-----------------------------------

theory-status, stat         Status of specified theory (parsed etc.)
*file-status, fstat         Status of theories of current file
all-theory-status, ats      Status of theories in using chain of theory
*all-files-status, afs      Status of files in context
using-status, us            Status of theories in using chain of theory
usedby-status, ys           Status of theories used by theory
proof-status, prs           Status of formula at cursor
theory-proof-status, tps    Status of all formulas in theory
all-proof-status, aps       Status of all formulas on using chain
proofchain-status, pcs      Analyze proof chain of formula at cursor
theorychain-status, tcs     Analyze proof chains of all formulas in theory


------------------------Prover Support Commands-------------------------------

edit-proof		    Edit the proof of the formula at cursor
			      (C-c C-c) offers to rerun the proof
revert-proof                Reverts the proof of the formula at cursor
                              to the previous one (toggles)
ancestry                    Display the ancestry of the current sequent
siblings                    Display the siblings of the current sequent


----------------------------Prover Commands-----------------------------------

Prover commands are currently typed in directly to lisp, by giving the
command with its arguments surrounded by parentheses and separated by
whitespace.  There are three categories of commands: primitive rules,
defined rules, and strategies.  Following these are sections describing
the arguments and the procedure for defining new rules and strategies.

Commands and arguments not surrounded by angle or square brackets must
be typed as given, though they are case insensitive.  Arguments in
brackets indicate a class of allowable values.  For example, 'fail' is
an instance of <command>.  Arguments in square brackets are optional; if
two or more arguments are optional then earlier ones must be given
values first.  Arguments followed by a '+' repeated one or more times,
surrounded by parentheses (parentheses are unnecessary for singletons).


Primitive Rules
---------------

(help [*])            - Describe all the prover commands
(help rules)	      - Describe primitive rules
(help defined-rules)  - Describe defined rules
(help strategies)     - Describe strategies
(help <command>)      - Describe specified command

(fail)                - Force backtracking

(skip)                - Do nothing

(postpone)            - Go to next unproved branch, if any

(undo [number])       - Undo proof back number steps (default 1)
(undo <command>)      - Undo proof back to specified command

(lisp <sexp>)         - Evaluate a Lisp expression

(propax)              - Check for axiom of form  G,a |- a,D

(delete <fnums>)      - Delete specified formulas

(apply <step>)        - Apply strategy as if it were a rule

(add-decl <pvs-decl>) - Add pvs-decl to the end of the current theory

(assert [fnums])      - Invokes decision procedures to simplify, prove,
                        or record formulas for future use.

(split [fnums])       - Conjunctively split formula

(dsimp [fnums])       - Disjunctively simplify chosen formulas

(lift-if [fnums])     - Lift IF occurrences to the top of chosen formulas

(lemma <lname> [substs])
                      - Add lemma with substitutions to the premises

(typepred <pvs-expr+>)
                      - Extract subtype constraints for expressions
                        and add to the premises

(iff [fnums])         - Convert top level Boolean equality into an IFF

(case <pvs-expr>)     - Split according to the truth or falsity of
                        the specified expression

(extensionality <pvs-type>)
                      - Add an extensionality premise derived from the type

(name <newname> <pvs-expr>)
                      - Introduce a <pvs-expr>=<newname> premise

(replace fnum [fnums] [R|L])
                      - Rewrite the given formula-numbers in the sequent
                        with the formula, either rightwards or leftwards

(beta [fnums] [R|L|nil])
                      - Beta-reduce specified formulas. If rewrite-flag is
                        R(L), then left(right)-hand-side is left undisturbed
                        for rewriting

(quant <fnum> <pvs-expr+> [copy?])
                      - Instantiate top quantifier in the formula

(skolem [fnum] [skolem-name+])
                      - Replace universally quantified variables with
                        new skolem constants

(hide <fnum+>)        - Hide the specified formulas

(reveal)              - Move all hidden formulas back to the sequent

(auto-rewrite <name1> ... <namei>)
                      - Automatically rewrite lemmas/definitions.

(auto-rewrite-theory <theory1> ... <theoryn>)
                      - Automatically rewrite relative to theories.


Defined Rules
-------------

(prop$)               - A black-box rule for propositional simplification

(ground$)             - Do propositional simplification followed by the
                        use of decision procedures

(rewrite-lemma <lname> <substs> [fnums])
                      - Rewrite using the given (conditional) rewrite rule and
                        substitution in the given sequent formulas

(rewrite <lname> [fnums1] [substs] [fnums2] [R|L|nil])
                      - Rewrite expressions in fnums2 after finding a
                        match for conclusion of lemma from fnums1.

(quant? [fnums1] [pvs-expr+] [fnums2] [copy?])
                      - Try to automatically instantiate a top-level quantifier
                        from fnums1 with matches from fnums2


Predefined Strategies
---------------------

(query*)              - Basic strategy that queries the user for the next step

(else <step1> <step2>)
                      - If step1 fails, then try step2,
                        else keep the the results of step1

(repeat <step>)       - Successively apply <step> to the main branch until
                        it does nothing

(repeat* <step>)      - Successively apply <step> to all branches until
                        it does nothing

(prop*)               - The propositional simplification strategy

(then <step1> <step2>)
                      - Apply step1, then step2 to resulting goal(s)
                        regardless of whether step1 succeeds

(then* <step1> ... <stepn>)
                      - Successively apply the steps

(spread <step> <step+>)
                      - Apply step and pair the steps in step+ with subgoals

(branch <step> <step+>)
                      - Like spread, applies step then pairs steps in step+
                        with the resulting subgoals, using the last step in
                        step+ for any excess subgoals

(ground*)             - Ground simplification strategy

(rerun)               - Strategy to rerun existing proof

(skolem! [fnums] [pvs-expr+])
                      - Skolemizes by automatically generating skolem constants

Prover Arguments
----------------

command               - Any of the commands above, or user-defined rules
                        and strategies

number                - A number

sexp                  - A lisp expression

fnums                 - A list of formula numbers.  These are the numbers 
                        that appear in brackets on the left side of the
                        sequent.  A '*' means all formulas, and is the
                        default. A '-' means all the premises, and a '+'
                        means all the conclusions.

step		      - The name of a strategy

pvs-decl	      - A PVS declaration string
pvs-type              - A PVS type string
pvs-expr	      - A PVS expression string
                        These will be typechecked in the context of the
                        theory containing the formula being proved

label		      - A label provided by the user to name the formulas

lname		      - The name of an axiom or formula visible to the
                        current theory

substs                - A list of substitution pairs of the form
                        (\"x\" \"f(a)\" \"y\" \"x + 1\"), which indicates the
                        simultaneous substitution of \"f(a)\" for \"x\"
                        and \"x + 1\" for \"y\"


Defining Rules and Strategies
-----------------------------

These must be defined in lisp.

(defrule <name> <formals> <definition> [docstring] [format-string])

(defstrat <name> <formals> <definition> [docstring] [format-string])"))
  (goto-char (point-min))
  (set-buffer-modified-p nil)
  (setq buffer-read-only t)
  (other-window 1))

